@@ -1,4 +1,4 @@
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 __author__ = "Kura"
 __email__ = "kura@kura.io"
 __license__ = "MIT"
@@ -8,4 +8,4 @@ __status__ = "Stable"
 __all__ = ['deiman']
 
 
-from deiman import Deiman
+from .deiman import Deiman
